@@ -4,7 +4,7 @@ import (
 	"time"
 
 	"cloud.google.com/go/civil"
-	"github.com/tufin/oasdiff/diff"
+	"github.com/oasdiff/oasdiff/diff"
 )
 
 const (
