@@ -4,8 +4,9 @@ const (
 	LangDefault = LangEn
 	LangEn      = "en"
 	LangRu      = "ru"
+	LangPtBr    = "pt-br"
 )
 
 func GetSupportedLanguages() []string {
-	return []string{LangEn, LangRu}
+	return []string{LangEn, LangRu, LangPtBr}
 }
