@@ -5,10 +5,10 @@ import (
 	"io"
 	"sort"
 
+	"github.com/oasdiff/oasdiff/checker"
+	"github.com/oasdiff/oasdiff/checker/localizations"
+	"github.com/oasdiff/oasdiff/formatters"
 	"github.com/spf13/cobra"
-	"github.com/tufin/oasdiff/checker"
-	"github.com/tufin/oasdiff/checker/localizations"
-	"github.com/tufin/oasdiff/formatters"
 	"golang.org/x/exp/slices"
 )
 
